"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getCredentials_1 = __importDefault(require("./utils/getCredentials"));
class ServerlessBetterCredentials {
    constructor(serverless, _, // no options are supported
    context) {
        this.hooks = {};
        const log = (context === null || context === void 0 ? void 0 : context.log) || console;
        this.serverless = serverless;
        this.provider = this.serverless.getProvider('aws');
        if (!this.provider) {
            log.error('serverless-better-credentials: only AWS is supported');
            return;
        }
        this.provider.getCredentials = getCredentials_1.default;
        log.debug('provider.getCredentials patched');
        this.hooks = { initialize: () => this.init() };
    }
    async init() {
        // Serverless treats the credentials object as if it is a synchronous and static map of
        // { accessKeyId, secretAccessKey, sessionToken? }.
        // However many types of AWS credentials mutate (refresh) over time and are asynchronous on
        // first access.
        // By running getPromise() on the (awaited) plug-in initialisation we can mimic an environment
        // where the key id, secret and token are set immediately, while still providing a valid
        // credentials class for the aws-sdk, etc. that supports refreshing.
        const { credentials } = this.provider.getCredentials();
        await credentials.getPromise();
    }
}
exports.default = ServerlessBetterCredentials;
//# sourceMappingURL=ServerlessBetterCredentials.js.map